summaryrefslogtreecommitdiff
path: root/test/unit/context/context_mm_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/context/context_mm_black.cpp')
-rw-r--r--test/unit/context/context_mm_black.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/context/context_mm_black.cpp b/test/unit/context/context_mm_black.cpp
index b0259e71e..2dbec57b6 100644
--- a/test/unit/context/context_mm_black.cpp
+++ b/test/unit/context/context_mm_black.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::context::ContextMemoryManager.
**
** Black box testing of CVC4::context::ContextMemoryManager.
**/
#include <cstring>
@@ -21,7 +21,7 @@
#include "context/context_mm.h"
#include "test.h"
-namespace CVC4 {
+namespace CVC5 {
using namespace context;
@@ -104,4 +104,4 @@ TEST_F(TestContextBlackMM, push_pop)
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::context::ContextMemoryManager.
+ ** \brief Black box testing of CVC5::context::ContextMemoryManager.
**
@@ -9,9 +9,9 @@
**
- ** Black box testing of CVC4::context::ContextMemoryManager.
+ ** Black box testing of CVC5::context::ContextMemoryManager.
**/
#include <cstring>